@@ -13,8 +13,12 @@ class KeysGenerator:
         self.inspect = inspect(self.db_worker.engine)
 
     def get_pk_constraint(self, table_name):
-        if 'constrained_columns' in self.inspect.get_pk_constraint(table_name):
-            return self.inspect.get_pk_constraint(table_name)['constrained_columns'][0]
+        if (
+            "constrained_columns" in self.inspect.get_pk_constraint(table_name)
+            and len(self.inspect.get_pk_constraint(table_name)["constrained_columns"])
+            > 0
+        ):
+            return self.inspect.get_pk_constraint(table_name)["constrained_columns"][0]
         columns = self.db_worker.get_columns(table_name)
         if "id" in columns and self.__check_identity(
             table_name=table_name, column="id"
@@ -36,8 +40,8 @@ class KeysGenerator:
 
         res = self.db_worker.conn.execute(select_st)
         res_lst = [dict(r) for r in res]
-        count_distinct = res_lst[0]['count_distinct_id']
-        count = res_lst[0]['count_id']
+        count_distinct = res_lst[0]["count_distinct_id"]
+        count = res_lst[0]["count_id"]
         if count_distinct == count:
             return True
         else:
