@@ -4,7 +4,7 @@ import sys
 import sqlalchemy
 import warnings
 from sqlalchemy.engine import create_engine
-from sqlalchemy import MetaData, Table
+from sqlalchemy import MetaData, Table, inspect
 
 warnings.filterwarnings("ignore")
 
@@ -91,6 +91,10 @@ class DataBaseWorker:
             result = connection.execute(query)
             return result
 
+    def is_table_exists(self, table):
+        insp = inspect(self.engine)
+        return insp.has_table(table, schema=self.schema)
+
     @property
     def meta(self):
         if "schema" in self.cred:
